
# Type: genotype to phenotypic feature association_subject




URI: [biolink:genotype_to_phenotypic_feature_association_subject](https://w3id.org/biolink/vocab/genotype_to_phenotypic_feature_association_subject)


## Domain and Range

[GenotypeToPhenotypicFeatureAssociation](GenotypeToPhenotypicFeatureAssociation.md) ->  <sub>REQ</sub> [Genotype](Genotype.md)

## Parents

 *  is_a: [subject](subject.md)

## Children


## Used by

 * [GenotypeToPhenotypicFeatureAssociation](GenotypeToPhenotypicFeatureAssociation.md)
